@@ -46,51 +46,51 @@ class FreebusyViewCalendar : public EventViews::ViewCalendar
 {
 public:
     virtual ~FreebusyViewCalendar() {}
-    bool isValid(const KCalCore::Incidence::Ptr &incidence) const Q_DECL_OVERRIDE
+    bool isValid(const KCalCore::Incidence::Ptr &incidence) const override
     {
         return isValid(incidence->uid());
     }
 
-    bool isValid(const QString &incidenceIdentifier) const Q_DECL_OVERRIDE
+    bool isValid(const QString &incidenceIdentifier) const override
     {
         return incidenceIdentifier.startsWith(QStringLiteral("fb-"));
     }
 
-    QString displayName(const KCalCore::Incidence::Ptr &incidence) const Q_DECL_OVERRIDE
+    QString displayName(const KCalCore::Incidence::Ptr &incidence) const override
     {
         Q_UNUSED(incidence);
         return i18n("Free/Busy calendar from %1", name);
     }
 
-    QColor resourceColor(const KCalCore::Incidence::Ptr &incidence) const Q_DECL_OVERRIDE
+    QColor resourceColor(const KCalCore::Incidence::Ptr &incidence) const override
     {
         bool ok = false;
         int status = incidence->customProperty(QStringLiteral("FREEBUSY").toLatin1(), QStringLiteral("STATUS").toLatin1()).toInt(&ok);
 
         if (!ok) {
-            return QColor(QStringLiteral("#555"));
+            return QColor(85, 85, 85);
         }
 
         switch (status) {
         case KCalCore::FreeBusyPeriod::Busy:
-            return QColor(QStringLiteral("#f00"));
+            return QColor(255, 0, 0);
         case KCalCore::FreeBusyPeriod::BusyTentative:
         case KCalCore::FreeBusyPeriod::BusyUnavailable:
-            return QColor(QStringLiteral("#f70"));
+            return QColor(255, 119, 0);
         case KCalCore::FreeBusyPeriod::Free:
-            return QColor(QStringLiteral("#0f0"));
+            return QColor(0, 255, 0);
         default:
-            return QColor(QStringLiteral("#555"));
+            return QColor(85, 85, 85);
         }
     }
 
-    QString iconForIncidence(const KCalCore::Incidence::Ptr &incidence) const Q_DECL_OVERRIDE
+    QString iconForIncidence(const KCalCore::Incidence::Ptr &incidence) const override
     {
         Q_UNUSED(incidence);
         return QString();
     }
 
-    KCalCore::Calendar::Ptr getCalendar() const Q_DECL_OVERRIDE
+    KCalCore::Calendar::Ptr getCalendar() const override
     {
         return mCalendar;
     }
